### -- NAMING CONVENTIONS --
# names for excitatory and inhibitory masses
EXC = "EXC"
INH = "INH"
# names for matrices
NODE_CONNECTIVITY = "local_connectivity"
NODE_DELAYS = "local_delays"
NETWORK_CONNECTIVITY = "connectivity"
NETWORK_DELAYS = "delays"

# speed for dummy fixed-point-dynamical variable
LAMBDA_SPEED = 10.0
